{% extends "account/base.html" %}

{% load i18n %}
{% load django_bootstrap5 %}

{% block head_title %}{% trans "Set Password" %}{% endblock %}
{% block title %}{% trans "Set Password" %}{% endblock %}

{% block accounts_content %}
  <div class="header_custom">
    <div class="branding_custom">
      <h1 class="site-name_custom"><a href="{% url 'account_signup' %}">{% trans "Set Password" %}</a></h1>
    </div>
  </div>
  <div class="main_form">
    <form method="POST" action="{% url 'account_set_password' %}" class="password_set">
      {% csrf_token %}
      {% bootstrap_form form %}
      <input type="submit" name="action" value="{% trans 'Set Password' %}"/>
    </form>

  </div>
{% endblock %}
