{% extends "account/base.html" %}

{% load i18n %}
{% load django_bootstrap5 %}

{% block head_title %}{% trans "Change Password" %}{% endblock %}
{% block title %}{% trans "Change Password" %}{% endblock %}

{% block accounts_content %}
  <div class="header_custom">
    <div class="branding_custom">
      <h1 class="site-name_custom"><a href="{% url 'account_change_password' %}">{% trans "Change Password" %}</a>
      </h1>
    </div>
  </div>
  <div class="main_form">
    <form method="POST" action="{% url 'account_change_password' %}" class="password_change">
      {% csrf_token %}
      {% bootstrap_form form %}
      {% trans "Change Password" as button_text %}
      {% bootstrap_button button_text button_type="submit" extra_classes="w-100" name="action" %}
      <a class="secondaryAction"
         href="{% url 'account_reset_password' %}">{% trans "Forgot Password?" %}</a>
    </form>
  </div>
{% endblock %}
