{% extends "account/base.html" %}
{% load django_bootstrap5 %}

{% load i18n %}

{% block head_title %}{% trans "Signup" %}{% endblock %}
{% block title %}{% trans "Signup" %}{% endblock %}


{% block accounts_content %}
  <div class="header_custom">
    <div class="branding_custom">
      <h1 class="site-name_custom"><a href="{% url 'account_signup' %}">{% trans "Sign Up" %}</a></h1>
    </div>
  </div>
  <div class="main_form">
    <p>
      {% trans 'Already have an account? Then please ' %}<a href="{{ login_url }}">{% trans 'sign in' %}</a>.
    </p>
    <form class="signup" id="signup_form" method="post" action="{% url 'account_signup' %}">
      {% csrf_token %}
      {% bootstrap_form form %}
      {% if redirect_field_value %}
        <input type="hidden" name="{{ redirect_field_name }}" value="{{ redirect_field_value }}"/>
      {% endif %}
      {% trans "Sign Up" as button_text %}
      {% bootstrap_button button_text button_type="submit" extra_classes="secondaryAction w-100" %}
    </form>
  </div>
{% endblock %}
