{% extends "account/base.html" %}

{% load i18n %}

{% block head_title %}{% trans "Verify Your E-mail Address" %}{% endblock %}

{% block accounts_content %}
  <div class="header_custom">
    <div class="branding_custom">
      <h1 class="site-name_custom"><a>{% trans "Verify Your E-mail Address" %}</a></h1>
    </div>
  </div>
  <div class="main_form">
    <p>{% blocktrans %}We have sent an e-mail to you for verification. Follow the link provided to finalize the signup
      process. Please contact us if you do not receive it within a few minutes.{% endblocktrans %}</p>
  </div>
{% endblock %}
