{% extends "account/base.html" %}

{% load i18n %}
{% load account %}

{% block head_title %}{% trans "Password Reset" %}{% endblock %}

{% block accounts_content %}
  <div class="header_custom">
    <div class="branding_custom">
      <h1 class="site-name_custom"><a href="{% url 'account_login' %}">{% trans "Password Reset" %}</a></h1>
    </div>
  </div>
  <div class="main_form">
    {% if user.is_authenticated %}
      {% include "account/snippets/already_logged_in.html" %}
    {% endif %}
    <p>
      {% blocktrans %}
        We have sent you an e-mail. Please contact us if you do not receive it within a few minutes.
      {% endblocktrans %}
    </p>
  </div>
{% endblock %}
