{% extends "account/base.html" %}

{% load i18n %}
{% load account %}
{% load django_bootstrap5 %}

{% block head_title %}{% trans "Password Reset" %}{% endblock %}
{% block title %}{% trans "Password Reset" %}{% endblock %}

{% block accounts_content %}
  <div class="header_custom">
    <div class="branding_custom">
      <h1 class="site-name_custom"><a href="{% url 'account_login' %}">{% trans "Password Reset" %}</a></h1>
    </div>
  </div>
  <div class="main_form">
    {% if user.is_authenticated %}
      {% include "account/snippets/already_logged_in.html" %}
    {% endif %}
    <p>{% trans "Forgotten your password? Enter your e-mail address below, and we'll send you an e-mail allowing you to reset it." %}</p>
    <form method="POST" action="{% url 'account_reset_password' %}" class="password_reset">
      {% csrf_token %}
      {% bootstrap_form form %}
      {% trans 'Reset My Password' as button_text %}
      {% bootstrap_button button_text button_type="submit" extra_classes="secondaryAction w-100" %}
    </form>
    <p>{% blocktrans %}Please contact us if you have any trouble resetting your password.{% endblocktrans %}</p>
  </div>
{% endblock %}
